@@ -132,7 +132,7 @@ module OmniAuth
   end
 
   module Utils
-  module_function
+  module_function # rubocop:disable Layout/IndentationWidth
 
     def form_css
       "<style type='text/css'>#{OmniAuth.config.form_css}</style>"
